==> haskell-postgresql-binary-0.12.1.3-11-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-postgresql-binary.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: postgresql-binary
version: 0.12.1.3
id: postgresql-binary-0.12.1.3-9OU5c7QUSrf1szpIEhSUYJ
key: postgresql-binary-0.12.1.3-9OU5c7QUSrf1szpIEhSUYJ
license: MIT
copyright: (c) 2014, Nikita Volkov
maintainer: Nikita Volkov <nikita.y.volkov@mail.ru>
author: Nikita Volkov <nikita.y.volkov@mail.ru>
homepage: https://github.com/nikita-volkov/postgresql-binary
synopsis: Encoders and decoders for the PostgreSQL'\''s binary format
description:
    An API for dealing with PostgreSQL'\''s binary data format.
    .
    It can be used to implement performant bindings to Postgres.
    E.g., <http://hackage.haskell.org/package/hasql "hasql">
    is based on this library.
    .
    It supports all Postgres versions starting from 8.3
    and is tested against 8.3, 9.3 and 9.5
    with the @integer_datetimes@ setting off and on.
category: PostgreSQL, Database, Codecs, Parsing
abi: 1be9f8ee75f95dafaf94a9fe2b1e6f81
exposed: True
exposed-modules:
    PostgreSQL.Binary.Data PostgreSQL.Binary.Decoding
    PostgreSQL.Binary.Encoding
hidden-modules: PostgreSQL.Binary.Encoding.Builders
                PostgreSQL.Binary.Prelude PostgreSQL.Binary.Integral
                PostgreSQL.Binary.Interval PostgreSQL.Binary.Numeric
                PostgreSQL.Binary.Time PostgreSQL.Binary.Inet
                PostgreSQL.Binary.BuilderPrim
import-dirs: /usr/lib/ghc-8.6.5/site-local/postgresql-binary-0.12.1.3
library-dirs: /usr/lib/ghc-8.6.5/site-local/postgresql-binary-0.12.1.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/postgresql-binary-0.12.1.3
hs-libraries: HSpostgresql-binary-0.12.1.3-9OU5c7QUSrf1szpIEhSUYJ
depends:
    aeson-1.4.4.0-B759jesA16BBzbLoqI31GW base-4.12.0.0
    base-prelude-1.3-4ZZNNsW3hao94Bjea11y2s
    binary-parser-0.5.5-8FV9WLyPomf73wodYxApuZ bytestring-0.10.8.2
    bytestring-strict-builder-0.4.5.3-KyMf095UTge2JtVa9bni1T
    containers-0.6.0.1 loch-th-0.2.2-3CPdVoaGmAI4E58ziaHpq7
    network-ip-0.3.0.2-EwJWLr80x3pDhM2V0g16yJ
    placeholders-0.1-BvqrCQDGi4R6ufjrVRZiOw
    scientific-0.3.6.2-L1dtV0bHm4E7J1We1UVw6b text-1.2.3.1 time-1.8.0.2
    transformers-0.5.6.2
    unordered-containers-0.2.10.0-8ZCNQorHEnr2Al0NbBIjXw
    uuid-1.3.13-LIaAFvnbb2aBMiL9u5bjma
    vector-0.12.0.3-2LEYu9M2i7lERDtz76XG3n
haddock-interfaces: /usr/share/doc/haskell-postgresql-binary/html/postgresql-binary.haddock
haddock-html: /usr/share/doc/haskell-postgresql-binary/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-postgresql-binary-0.12.1.3-16-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-postgresql-binary.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: postgresql-binary
version: 0.12.1.3
id: postgresql-binary-0.12.1.3-GtvOGFd2rDz2uPW8dR2bDT
key: postgresql-binary-0.12.1.3-GtvOGFd2rDz2uPW8dR2bDT
license: MIT
copyright: (c) 2014, Nikita Volkov
maintainer: Nikita Volkov <nikita.y.volkov@mail.ru>
author: Nikita Volkov <nikita.y.volkov@mail.ru>
homepage: https://github.com/nikita-volkov/postgresql-binary
synopsis: Encoders and decoders for the PostgreSQL'\''s binary format
description:
    An API for dealing with PostgreSQL'\''s binary data format.
    .
    It can be used to implement performant bindings to Postgres.
    E.g., <http://hackage.haskell.org/package/hasql "hasql">
    is based on this library.
    .
    It supports all Postgres versions starting from 8.3
    and is tested against 8.3, 9.3 and 9.5
    with the @integer_datetimes@ setting off and on.
category: PostgreSQL, Database, Codecs, Parsing
abi: b448646f0cef76f7c40e86d86a21d97f
exposed: True
exposed-modules:
    PostgreSQL.Binary.Data PostgreSQL.Binary.Decoding
    PostgreSQL.Binary.Encoding
hidden-modules: PostgreSQL.Binary.Encoding.Builders
                PostgreSQL.Binary.Prelude PostgreSQL.Binary.Integral
                PostgreSQL.Binary.Interval PostgreSQL.Binary.Numeric
                PostgreSQL.Binary.Time PostgreSQL.Binary.Inet
                PostgreSQL.Binary.BuilderPrim
import-dirs: /usr/lib/ghc-8.6.5/site-local/postgresql-binary-0.12.1.3
library-dirs: /usr/lib/ghc-8.6.5/site-local/postgresql-binary-0.12.1.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/postgresql-binary-0.12.1.3
hs-libraries: HSpostgresql-binary-0.12.1.3-GtvOGFd2rDz2uPW8dR2bDT
depends:
    aeson-1.4.6.0-6SSxkzo3COEI5l1mOYJmxL base-4.12.0.0
    base-prelude-1.3-4ZZNNsW3hao94Bjea11y2s
    binary-parser-0.5.5-8FV9WLyPomf73wodYxApuZ bytestring-0.10.8.2
    bytestring-strict-builder-0.4.5.3-5dHttviBvLGIIjKfKY5Xp1
    containers-0.6.0.1 loch-th-0.2.2-3CPdVoaGmAI4E58ziaHpq7
    network-ip-0.3.0.3-HOIToL51IzsKYaYjZPsuEQ
    placeholders-0.1-BvqrCQDGi4R6ufjrVRZiOw
    scientific-0.3.6.2-L1dtV0bHm4E7J1We1UVw6b text-1.2.3.1 time-1.8.0.2
    transformers-0.5.6.2
    unordered-containers-0.2.10.0-8ZCNQorHEnr2Al0NbBIjXw
    uuid-1.3.13-LIaAFvnbb2aBMiL9u5bjma
    vector-0.12.0.3-2LEYu9M2i7lERDtz76XG3n
haddock-interfaces: /usr/share/doc/haskell-postgresql-binary/html/postgresql-binary.haddock
haddock-html: /usr/share/doc/haskell-postgresql-binary/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
